pub struct StateUpdate {
pub derp: Option<DerpMap>,
pub node: Option<Node>,
pub peer_update: Option<PeerUpdate>,
pub ping: Option<PingRequest>,
pub packetfilter: Option<FilterUpdate>,
pub pop_browser_url: Option<Url>,
pub dial_plan: Option<DialPlan>,
}Expand description
An update to the netmap state produced from a mapresponse.
Fields
derp: Option<DerpMap>New derp map is available.
node: Option<Node>New self-node.
peer_update: Option<PeerUpdate>Updates to the set of peers in the netmap.
ping: Option<PingRequest>Send a ping request.
packetfilter: Option<FilterUpdate>Update to the packet filter.
pop_browser_url: Option<Url>This URL should be displayed to the user or opened in their browser automatically.
dial_plan: Option<DialPlan>New dial plan sent by control.