pub enum DialPlan {
UseDns,
Plan(Vec<DialCandidate>),
}Expand description
A plan to connect to the control plane, supplied as part of a netmap update.
Variants
UseDns
Use system DNS to resolve the control plane’s IP address.
Plan(Vec<DialCandidate>)
Use the contained plan to connect to the control plane.