#[non_exhaustive]pub enum InternalErrorKind {
Url,
Http,
SerDe,
Io,
MessageFormat,
Utf8,
NoiseHandshake,
Challenge,
MachineAuthorization,
}Expand description
What kind of internal error has occurred.
This is intended to be useful for reporting a crash to an end user, rather than being handled.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Url
An error in URL parsing.
Http
An unsuccessful HTTP request or upgrade.
SerDe
An error in serialization or deserialization.
Io
An error in I/O.
MessageFormat
An invalid message format.
Utf8
An error parsing a string as UTF8.
NoiseHandshake
Noise framework handshake.
Challenge
Tailscale challenge packet.
MachineAuthorization
The user’s machine was not authorized to register with a Tailnet and there is no URL for the user to authorize at.