ControlDialer

Struct ControlDialer 

pub struct ControlDialer { /* private fields */ }
Manages state for control dial plan and handles selection of successive dial candidates.

Implementations

Source

impl ControlDialer

pub fn update_dial_plan(&mut self, plan: &DialPlan) -> bool

Update the stored dial plan with the new plan.

Returns whether the dial plan changed. Resubmission of the same dial plan is idempotent.

pub fn clear_attempted(&mut self)

Clear the set of attempted dial candidates.

This will cause future connection attempts to retry all available dialers in priority order.

pub fn next_dialer(&mut self) -> impl TcpDialer + Debug

Get the next dialer candidate from the dial plan.

If all dialers have already been tried, falls back to system DNS.

NB: the returned TcpDialer does not mark its corresponding candidate as having been attempted until TcpDialer::dial is called – it is fine semantically to drop the returned dialer without calling dial.

pub async fn full_connect_next( &mut self, url: &Url, machine_keys: &MachineKeyPair, ) -> Result<Http2<BytesBody>, ConnectionError>

Convenience wrapper for next_dialer followed by complete_connection.