pub enum Error {
MachineNotAuthorized(Url),
InvalidUrl(Url),
Registration(String),
NetworkError(Operation),
Internal(InternalErrorKind, Operation),
}Expand description
An error which occurred while connecting to the control server or control plane.
Variants
MachineNotAuthorized(Url)
A machine was not authorized by control to join tailnet; authorize via the supplied URL.
InvalidUrl(Url)
The user supplied an invalid URL.
Registration(String)
Control rejected registration with a specific reason (e.g. a bad/expired/unknown auth key).
The string is control’s verbatim RegisterResponse.Error message.
NetworkError(Operation)
Some kind of networking error.
These might be addressed by retrying, or might be an unresolvable error.
Operation is intended to be informational, rather then inspected during handling.
Internal(InternalErrorKind, Operation)
An internal error that users of the library are not expected to handle.
InternalErrorKind and Operation are intended to be informational, rather then
inspected during handling.